@@ -2,7 +2,7 @@
 
 # slip.dbus.mainloop -- mainloop wrappers
 #
-# Copyright © 2009 Red Hat, Inc.
+# Copyright © 2009, 2012 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,18 +15,19 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Authors:
 # Nils Philippsen <nils@redhat.com>
 
-"""This module contains mainloop wrappers."""
+"""This module contains mainloop wrappers.
+
+Currently only glib main loops are supported."""
+
+from __future__ import absolute_import
 
 __all__ = ("MainLoop", "set_type")
 
-_mainloop_class = None
-
 
 class MainLoop(object):
     """An abstract main loop wrapper class and factory.
@@ -36,11 +37,32 @@ class MainLoop(object):
 
     Actual main loop wrapper classes are derived from this class."""
 
+    __mainloop_class = None
+
     def __new__(cls, *args, **kwargs):
         global _mainloop_class
-        if _mainloop_class is None:
-            set_type("glib")
-        return super(MainLoop, cls).__new__(_mainloop_class, *args, **kwargs)
+        if MainLoop._mainloop_class is None:
+            MainLoop.set_type("glib")
+        return super(MainLoop, cls).__new__(
+            MainLoop.__mainloop_class, *args, **kwargs)
+
+    @classmethod
+    def set_type(cls, mltype):
+        """Set a main loop type for non-blocking interfaces.
+
+        mltype: "glib" (currently only glib main loops are supported)"""
+
+        if MainLoop.__mainloop_class is not None:
+            raise RuntimeError("The main loop type can only be set once.")
+
+        ml_type_class = {"glib": GlibMainLoop}
+
+        if mltype in ml_type_class:
+            MainLoop.__mainloop_class = ml_type_class[mltype]
+        else:
+            raise ValueError(
+                "'%s' is not one of the valid main loop types:\n%s" %
+                (mltype, ", ".join(ml_type_class)))
 
     def pending(self):
         """Returns if there are pending events."""
@@ -72,7 +94,7 @@ class MainLoop(object):
 class GlibMainLoop(MainLoop):
 
     def __init__(self):
-        from slip._wrappers import _gobject
+        from .._wrappers import _gobject
         ml = _gobject.MainLoop()
         ctx = ml.get_context()
 
@@ -86,19 +108,12 @@ class GlibMainLoop(MainLoop):
 def set_type(mltype):
     """Set a main loop type for non-blocking interfaces.
 
-    mltype: "glib" (currently only glib main loops are supported)"""
+    mltype: "glib" (currently only glib main loops are supported)
 
-    global _mainloop_class
+    Deprecated, use MainLoop.set_type() instead."""
 
-    if _mainloop_class is not None:
-        raise RuntimeError("The main loop type can only be set once.")
-
-    ml_type_class = {"glib": GlibMainLoop}
-
-    if mltype in ml_type_class:
-        _mainloop_class = ml_type_class[mltype]
-    else:
-        raise ValueError("'%s' is not one of the valid main loop types (%s)." %
-                          (mltype, ",".join(ml_type_class.keys())))
+    from warnings import warn
 
+    warn("use MainLoop.set_type() instead", DeprecationWarning)
 
+    MainLoop.set_type(mltype)
