@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
 
+# slip.util.files -- file helper functions
 #
 # Copyright © 2009, 2010, 2012 Red Hat, Inc.
-# Authors:
-# Nils Philippsen <nils@redhat.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +16,18 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Authors:
+# Nils Philippsen <nils@redhat.com>
 
 """This module contains helper functions for dealing with files."""
 
+from __future__ import absolute_import
+
+# ensure range() returns a generator
+if 'xrange' in dir(__builtins__):
+    range = xrange
+
 __all__ = ["issamefile", "linkfile", "copyfile", "linkorcopyfile",
            "overwrite_safely"]
 
@@ -42,7 +50,7 @@ def _issamefile(path1, path2):
 def issamefile(path1, path2, catch_stat_exceptions=[]):
     """Check whether two paths point to the same file (i.e. are hardlinked)."""
 
-    if catch_stat_exceptions == True:
+    if catch_stat_exceptions is True:
         catch_stat_exceptions = Exception
 
     try:
@@ -64,11 +72,11 @@ def linkfile(srcpath, dstpath):
     dstbname = os.path.basename(dstpath)
 
     hardlinked = False
-    for attempt in xrange(tempfile.TMP_MAX):
+    for attempt in range(tempfile.TMP_MAX):
         _dsttmp = tempfile.mktemp(prefix=dstbname + os.extsep, dir=dstdname)
         try:
             os.link(srcpath, _dsttmp)
-        except OSError, e:
+        except OSError as e:
             if e.errno == errno.EEXIST:
 
                 # try another name
@@ -98,8 +106,8 @@ def copyfile(srcpath, dstpath, copy_mode_from_dst=True, run_restorecon=True):
     dstbname = os.path.basename(dstpath)
 
     srcfile = open(srcpath, "rb")
-    dsttmpfile = tempfile.NamedTemporaryFile(prefix=dstbname + os.path.extsep,
-            dir=dstdname, delete=False)
+    dsttmpfile = tempfile.NamedTemporaryFile(
+        prefix=dstbname + os.path.extsep, dir=dstdname, delete=False)
 
     mode_copied = False
 
@@ -138,15 +146,16 @@ def copyfile(srcpath, dstpath, copy_mode_from_dst=True, run_restorecon=True):
         selinux.restorecon(dstpath)
 
 
-def linkorcopyfile(srcpath, dstpath, copy_mode_from_dst=True,
-    run_restorecon=True):
+def linkorcopyfile(
+    srcpath, dstpath, copy_mode_from_dst=True, run_restorecon=True):
+
     """First attempt to hardlink srcpath to dstpath, if hardlinking isn't
     possible, attempt copying srcpath to dstpath."""
 
     try:
         linkfile(srcpath, dstpath)
         return
-    except OSError, e:
+    except OSError as e:
         if e.errno not in (errno.EMLINK, errno.EPERM, errno.EXDEV):
 
             # don't bother copying
@@ -160,6 +169,7 @@ def linkorcopyfile(srcpath, dstpath, copy_mode_from_dst=True,
 
     copyfile(srcpath, dstpath, copy_mode_from_dst, run_restorecon)
 
+
 def symlink_atomically(srcpath, dstpath, force=False, preserve_context=True):
     """Create a symlink, optionally replacing dstpath atomically, optionally
     setting or preserving SELinux context."""
@@ -177,7 +187,7 @@ def symlink_atomically(srcpath, dstpath, force=False, preserve_context=True):
             ret, ctx = selinux.lgetfilecon(dstpath)
             if ret < 0:
                 raise RuntimeError("getfilecon(%r) failed" % dstpath)
-        except OSError, e:
+        except OSError as e:
             if e.errno == errno.ENOENT:
                 run_restorecon = True
             else:
@@ -189,11 +199,12 @@ def symlink_atomically(srcpath, dstpath, force=False, preserve_context=True):
             selinux.restorecon(dstpath)
     else:
         dsttmp = None
-        for attempt in xrange(tempfile.TMP_MAX):
-            _dsttmp = tempfile.mktemp(prefix=dstbname + os.extsep, dir=dstdname)
+        for attempt in range(tempfile.TMP_MAX):
+            _dsttmp = tempfile.mktemp(
+                prefix=dstbname + os.extsep, dir=dstdname)
             try:
                 os.symlink(srcpath, _dsttmp)
-            except OSError, e:
+            except OSError as e:
                 if e.errno == errno.EEXIST:
                     # try again
                     continue
@@ -203,8 +214,9 @@ def symlink_atomically(srcpath, dstpath, force=False, preserve_context=True):
                 break
 
         if dsttmp is None:
-            raise IOError(errno.EEXIST,
-                    "No suitable temporary symlink could be created.")
+            raise IOError(
+                errno.EEXIST,
+                "No suitable temporary symlink could be created.")
 
         if preserve_context and not run_restorecon:
             selinux.lsetfilecon(dsttmp, ctx)
@@ -219,6 +231,7 @@ def symlink_atomically(srcpath, dstpath, force=False, preserve_context=True):
         if run_restorecon:
             selinux.restorecon(dstpath)
 
+
 def overwrite_safely(path, content, preserve_mode=True, preserve_context=True):
     """Safely overwrite a file by creating a temporary file in the same
     directory, writing it, moving it over the original file, eventually
